@@ -14,30 +14,21 @@
  * limitations under the License.
  */
 
-/******************************************************************************
-globus_thread_pthreads.c
+#ifndef GLOBUS_DONT_DOCUMENT_INTERNAL
 
-Description:
+/**
+ * @file globus_thread_pthreads.c
+ * @brief POSIX Threads Bindings
+ */
 
-  Bindings for the Globus threads package, to be used when Globus has been
-  configured to use POSIX threads.
-
-CVS Information:
-
-  $Source: /home/globdev/CVS/globus-packages/common/source/library/globus_thread_pthreads.c,v $
-  $Date: 2011/02/03 21:46:23 $
-  $Revision: 1.11 $
-  $State: Exp $
-  $Author: bester $
-******************************************************************************/
-#include "config.h"
+#include "globus_i_common_config.h"
 #include "globus_common.h"
 #include "globus_thread.h"
 #include "globus_thread_common.h"
 #include "globus_i_thread.h"
 #include "version.h"
 
-#if HAVE_PTHREAD
+#if _POSIX_THREADS
 
 #if defined __GNUC__ && defined __EXCEPTIONS
 #undef __EXCEPTIONS
@@ -90,8 +81,7 @@ globus_l_pthread_get_impl(void);
 static int globus_l_pthread_activate();
 static int globus_l_pthread_deactivate();
 
-globus_module_descriptor_t
-globus_extension_module =
+GlobusExtensionDefineModule(globus_thread_pthread) = 
 {
     "globus_thread_pthreads",
     globus_l_pthread_activate,
@@ -107,7 +97,7 @@ globus_l_pthread_pre_activate( void )
 {
   int rc;
 
-#ifndef WIN32
+#ifndef _WIN32
     rc = globus_i_thread_ignore_sigpipe();
 #endif
     return rc;
@@ -352,15 +342,6 @@ globus_l_pthread_preemptive_threads(void)
 
 
 
-/*
- * globus_threadattr_init()
- */
-static
-int
-globus_l_pthread_threadattr_init(globus_threadattr_t *attr)
-{
-    return pthread_attr_init(&attr->pthread);
-}
 
 /*
  * globus_threadattr_destroy()
@@ -370,35 +351,6 @@ int globus_threadattr_destroy(globus_threadattr_t *attr)
     return pthread_attr_destroy(&attr->pthread);
 }
 
-/*
- * globus_threadattr_setstacksize()
- */
-int globus_threadattr_setstacksize(globus_threadattr_t *attr,
-                                   size_t stacksize)
-{
-#if _POSIX_THREAD_ATTR_STACKSIZE > 0
-    return pthread_attr_setstacksize(&attr->pthread, stacksize);
-#else
-    return ENOTSUP;
-#endif
-}
-
-/*
- * globus_threadattr_getstacksize()
- */
-static
-int
-globus_threadattr_getstacksize(
-    globus_threadattr_t *               attr,
-    size_t *                            stacksize)
-{
-#if _POSIX_THREAD_ATTR_STACKSIZE > 0
-    return pthread_attr_getstacksize(&attr->pthread, stacksize);
-#else
-    return EINVAL;
-#endif
-}
-
 /*
  * globus_thread_key_create()
  */
@@ -426,9 +378,11 @@ int
 globus_l_pthread_thread_key_delete(
     globus_thread_key_t                 key)
 {
-    int rc;
+    int rc=0;
+#ifndef __MINGW32__
     rc = pthread_key_delete(key.pthread);
     globus_i_thread_test_rc(rc, _GCSL("GLOBUSTHREAD: globus_thread_key_delete() failed\n"));
+#endif
     return(rc);
 } /* globus_thread_key_delete() */
 
@@ -825,7 +779,7 @@ globus_l_pthread_cond_broadcast(
     }
 } /* globus_cond_broadcast() */
 
-#ifndef TARGET_ARCH_WIN32
+#if !defined(_WIN32) && !defined(__MINGW32__)
 static
 int
 globus_l_pthread_thread_sigmask(
@@ -919,7 +873,7 @@ static globus_thread_impl_t globus_l_pthread_impl =
     globus_l_pthread_thread_setspecific,
     globus_l_pthread_thread_yield,
     globus_l_pthread_thread_exit,
-#ifndef TARGET_ARCH_WIN32
+#if !defined(_WIN32) && !defined(__MINGW32__)
     globus_l_pthread_thread_sigmask,
     globus_l_pthread_thread_kill,
 #else
@@ -943,4 +897,6 @@ globus_l_pthread_get_impl(void)
 {
     return &globus_l_pthread_impl;
 }
-#endif /* HAVE_PTHREAD */
+#endif /* _POSIX_THREADS */
+
+#endif /* GLOBUS_DONT_DOCUMENT_INTERNAL */
